# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.config_values import ConfigValues
from ..types.source_connection import SourceConnection
from ..types.source_connection_job import SourceConnectionJob
from ..types.source_connection_list_item import SourceConnectionListItem
from .raw_client import AsyncRawSourceConnectionsClient, RawSourceConnectionsClient
from .types.source_connection_update_auth_fields import SourceConnectionUpdateAuthFields

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SourceConnectionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSourceConnectionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSourceConnectionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSourceConnectionsClient
        """
        return self._raw_client

    def list_source_connections(
        self,
        *,
        collection: typing.Optional[str] = None,
        skip: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[SourceConnectionListItem]:
        """
        List source connections across your organization.

        <br/><br/>
        By default, returns ALL source connections from every collection in your
        organization. Use the 'collection' parameter to filter results to a specific
        collection. This is useful for getting an overview of all your data sources
        or managing connections within a particular collection.

        Parameters
        ----------
        collection : typing.Optional[str]
            Filter source connections by collection readable ID

        skip : typing.Optional[int]
            Number of source connections to skip for pagination

        limit : typing.Optional[int]
            Maximum number of source connections to return (1-1000)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[SourceConnectionListItem]
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.list_source_connections()
        """
        _response = self._raw_client.list_source_connections(
            collection=collection, skip=skip, limit=limit, request_options=request_options
        )
        return _response.data

    def create_source_connection(
        self,
        *,
        name: str,
        short_name: str,
        description: typing.Optional[str] = OMIT,
        config_fields: typing.Optional[ConfigValues] = OMIT,
        collection: typing.Optional[str] = OMIT,
        cron_schedule: typing.Optional[str] = OMIT,
        auth_fields: typing.Optional[ConfigValues] = OMIT,
        sync_immediately: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Create a new source connection to sync data into your collection.

        <br/><br/>

        **This endpoint only works for sources that do not use OAuth2.0.**
        Sources that do use OAuth2.0 like Google Drive, Slack, or HubSpot must be
        connected through the UI where you can complete the OAuth consent flow.<br/><br/>

        Credentials for a source have to be provided using the `auth_fields` field.
        Currently, it is not automatically checked if the provided credentials are valid.
        If they are not valid, the data synchronization will fail.<br/><br/>

        Check the documentation of a specific source (for example
        [Github](https://docs.airweave.ai/docs/connectors/github)) to see what kind
        of authentication is used.

        Parameters
        ----------
        name : str
            Human-readable name for the source connection. This helps you identify the connection in the UI and should clearly describe what data it connects to.

        short_name : str
            Technical identifier of the source type that determines which connector to use for data synchronization.

        description : typing.Optional[str]
            Optional detailed description of what this source connection provides. Use this to document the purpose, data types, or any special considerations for this connection.

        config_fields : typing.Optional[ConfigValues]
            Source-specific configuration parameters required for data extraction. These vary by source type and control how data is retrieved (e.g., database queries, API filters, file paths). Check the documentation of a specific source (for example [Github](https://docs.airweave.ai/docs/connectors/github)) to see what is required.

        collection : typing.Optional[str]
            Readable ID of the collection where synced data will be stored. If not provided, a new collection will be automatically created.

        cron_schedule : typing.Optional[str]
            Cron expression for automatic data synchronization schedule. If not provided, data will only sync when manually triggered. Use standard cron format: minute hour day month weekday.

        auth_fields : typing.Optional[ConfigValues]
            Authentication credentials required to access the data source. The required fields vary by source type. Check the documentation of a specific source (for example [Github](https://docs.airweave.ai/docs/connectors/github)) to see what is required.

        sync_immediately : typing.Optional[bool]
            Whether to start an initial data synchronization immediately after creating the connection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.create_source_connection(
            name="GitHub - Airweave Repository",
            description="Sync code and documentation from our main repository",
            config_fields={"branch": "main"},
            short_name="github",
            collection="engineering-docs",
            cron_schedule="0 */6 * * *",
            auth_fields={
                "personal_access_token": "ghp_xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
                "repo_name": "airweave-ai/airweave",
            },
            sync_immediately=True,
        )
        """
        _response = self._raw_client.create_source_connection(
            name=name,
            short_name=short_name,
            description=description,
            config_fields=config_fields,
            collection=collection,
            cron_schedule=cron_schedule,
            auth_fields=auth_fields,
            sync_immediately=sync_immediately,
            request_options=request_options,
        )
        return _response.data

    def get_source_connection(
        self,
        source_connection_id: str,
        *,
        show_auth_fields: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Retrieve a specific source connection by its ID.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        show_auth_fields : typing.Optional[bool]
            Whether to reveal authentication credentials.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.get_source_connection(
            source_connection_id="source_connection_id",
        )
        """
        _response = self._raw_client.get_source_connection(
            source_connection_id, show_auth_fields=show_auth_fields, request_options=request_options
        )
        return _response.data

    def update_source_connection(
        self,
        source_connection_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        auth_fields: typing.Optional[SourceConnectionUpdateAuthFields] = OMIT,
        config_fields: typing.Optional[ConfigValues] = OMIT,
        cron_schedule: typing.Optional[str] = OMIT,
        connection_id: typing.Optional[str] = OMIT,
        white_label_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Update a source connection's properties.

        <br/><br/>

        Modify the configuration of an existing source connection including its name,
        authentication credentials, configuration fields, sync schedule, or source-specific settings.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection to update

        name : typing.Optional[str]
            Updated name for the source connection. Must be between 4 and 42 characters.

        description : typing.Optional[str]
            Updated description of what this source connection provides.

        auth_fields : typing.Optional[SourceConnectionUpdateAuthFields]
            Updated authentication credentials for the data source. Provide new credentials to refresh or update authentication.

        config_fields : typing.Optional[ConfigValues]
            Source-specific configuration parameters required for data extraction. These vary by source type and control how data is retrieved (e.g., database queries, API filters, file paths). Check the documentation of a specific source (for example [Github](https://docs.airweave.ai/docs/connectors/github)) to see what is required.

        cron_schedule : typing.Optional[str]
            Updated cron expression for automatic synchronization schedule. Set to null to disable automatic syncing.

        connection_id : typing.Optional[str]
            Internal connection identifier. This is typically managed automatically and should not be modified manually.

        white_label_id : typing.Optional[str]
            ID of the white label integration. Used for custom OAuth integrations with your own branding.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.update_source_connection(
            source_connection_id="source_connection_id",
            name="GitHub - Updated Engineering Documentation",
            description="Updated: Now includes API documentation and code examples from multiple repositories",
            auth_fields={
                "personal_access_token": "ghp_yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy",
                "repo_name": "airweave-ai/engineering-docs",
            },
            config_fields={"branch": "develop"},
            cron_schedule="0 */4 * * *",
        )
        """
        _response = self._raw_client.update_source_connection(
            source_connection_id,
            name=name,
            description=description,
            auth_fields=auth_fields,
            config_fields=config_fields,
            cron_schedule=cron_schedule,
            connection_id=connection_id,
            white_label_id=white_label_id,
            request_options=request_options,
        )
        return _response.data

    def delete_source_connection(
        self,
        source_connection_id: str,
        *,
        delete_data: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Delete a source connection.

        <br/><br/>

        Permanently removes the source connection configuration and credentials.
        By default, previously synced data remains in your destination systems for continuity.
        Use delete_data=true to also remove all associated data from destination systems.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection to delete

        delete_data : typing.Optional[bool]
            Whether to also delete all synced data from destination systems

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.delete_source_connection(
            source_connection_id="source_connection_id",
        )
        """
        _response = self._raw_client.delete_source_connection(
            source_connection_id, delete_data=delete_data, request_options=request_options
        )
        return _response.data

    def run_source_connection(
        self,
        source_connection_id: str,
        *,
        access_token: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnectionJob:
        """
        Manually trigger a data sync for this source connection.

        <br/><br/>
        Starts an immediate synchronization job that extracts fresh data from your source,
        transforms it according to your configuration, and updates the destination systems.
        The job runs asynchronously and endpoint returns immediately with tracking information.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection to sync

        access_token : typing.Optional[str]
            This parameter gives you the ability to start a sync job with an access token for an OAuth2.0 source directly instead of using the credentials that Airweave has stored for you. Learn more about direct token injection [here](https://docs.airweave.ai/direct-token-injection).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnectionJob
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.run_source_connection(
            source_connection_id="source_connection_id",
        )
        """
        _response = self._raw_client.run_source_connection(
            source_connection_id, access_token=access_token, request_options=request_options
        )
        return _response.data

    def list_source_connection_jobs(
        self, source_connection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[SourceConnectionJob]:
        """
        List all sync jobs for a source connection.

        <br/><br/>
        Returns the complete history of data synchronization jobs including successful syncs,
        failed attempts, and currently running operations.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[SourceConnectionJob]
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.list_source_connection_jobs(
            source_connection_id="source_connection_id",
        )
        """
        _response = self._raw_client.list_source_connection_jobs(source_connection_id, request_options=request_options)
        return _response.data

    def get_source_connection_job(
        self, source_connection_id: str, job_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SourceConnectionJob:
        """
        Get detailed information about a specific sync job.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        job_id : str
            The unique identifier of the sync job

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnectionJob
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.get_source_connection_job(
            source_connection_id="source_connection_id",
            job_id="job_id",
        )
        """
        _response = self._raw_client.get_source_connection_job(
            source_connection_id, job_id, request_options=request_options
        )
        return _response.data

    def cancel_source_connection_job(
        self, source_connection_id: str, job_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SourceConnectionJob:
        """
        Cancel a running sync job.

        <br/><br/>
        Sends a cancellation signal to stop an in-progress data synchronization.
        The job will complete its current operation and then terminate gracefully.
        Only jobs in 'created', 'pending', or 'in_progress' states can be cancelled.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        job_id : str
            The unique identifier of the sync job to cancel

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnectionJob
            Successful Response

        Examples
        --------
        from airweave import AirweaveSDK

        client = AirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )
        client.source_connections.cancel_source_connection_job(
            source_connection_id="source_connection_id",
            job_id="job_id",
        )
        """
        _response = self._raw_client.cancel_source_connection_job(
            source_connection_id, job_id, request_options=request_options
        )
        return _response.data


class AsyncSourceConnectionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSourceConnectionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSourceConnectionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSourceConnectionsClient
        """
        return self._raw_client

    async def list_source_connections(
        self,
        *,
        collection: typing.Optional[str] = None,
        skip: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[SourceConnectionListItem]:
        """
        List source connections across your organization.

        <br/><br/>
        By default, returns ALL source connections from every collection in your
        organization. Use the 'collection' parameter to filter results to a specific
        collection. This is useful for getting an overview of all your data sources
        or managing connections within a particular collection.

        Parameters
        ----------
        collection : typing.Optional[str]
            Filter source connections by collection readable ID

        skip : typing.Optional[int]
            Number of source connections to skip for pagination

        limit : typing.Optional[int]
            Maximum number of source connections to return (1-1000)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[SourceConnectionListItem]
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.list_source_connections()


        asyncio.run(main())
        """
        _response = await self._raw_client.list_source_connections(
            collection=collection, skip=skip, limit=limit, request_options=request_options
        )
        return _response.data

    async def create_source_connection(
        self,
        *,
        name: str,
        short_name: str,
        description: typing.Optional[str] = OMIT,
        config_fields: typing.Optional[ConfigValues] = OMIT,
        collection: typing.Optional[str] = OMIT,
        cron_schedule: typing.Optional[str] = OMIT,
        auth_fields: typing.Optional[ConfigValues] = OMIT,
        sync_immediately: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Create a new source connection to sync data into your collection.

        <br/><br/>

        **This endpoint only works for sources that do not use OAuth2.0.**
        Sources that do use OAuth2.0 like Google Drive, Slack, or HubSpot must be
        connected through the UI where you can complete the OAuth consent flow.<br/><br/>

        Credentials for a source have to be provided using the `auth_fields` field.
        Currently, it is not automatically checked if the provided credentials are valid.
        If they are not valid, the data synchronization will fail.<br/><br/>

        Check the documentation of a specific source (for example
        [Github](https://docs.airweave.ai/docs/connectors/github)) to see what kind
        of authentication is used.

        Parameters
        ----------
        name : str
            Human-readable name for the source connection. This helps you identify the connection in the UI and should clearly describe what data it connects to.

        short_name : str
            Technical identifier of the source type that determines which connector to use for data synchronization.

        description : typing.Optional[str]
            Optional detailed description of what this source connection provides. Use this to document the purpose, data types, or any special considerations for this connection.

        config_fields : typing.Optional[ConfigValues]
            Source-specific configuration parameters required for data extraction. These vary by source type and control how data is retrieved (e.g., database queries, API filters, file paths). Check the documentation of a specific source (for example [Github](https://docs.airweave.ai/docs/connectors/github)) to see what is required.

        collection : typing.Optional[str]
            Readable ID of the collection where synced data will be stored. If not provided, a new collection will be automatically created.

        cron_schedule : typing.Optional[str]
            Cron expression for automatic data synchronization schedule. If not provided, data will only sync when manually triggered. Use standard cron format: minute hour day month weekday.

        auth_fields : typing.Optional[ConfigValues]
            Authentication credentials required to access the data source. The required fields vary by source type. Check the documentation of a specific source (for example [Github](https://docs.airweave.ai/docs/connectors/github)) to see what is required.

        sync_immediately : typing.Optional[bool]
            Whether to start an initial data synchronization immediately after creating the connection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.create_source_connection(
                name="GitHub - Airweave Repository",
                description="Sync code and documentation from our main repository",
                config_fields={"branch": "main"},
                short_name="github",
                collection="engineering-docs",
                cron_schedule="0 */6 * * *",
                auth_fields={
                    "personal_access_token": "ghp_xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
                    "repo_name": "airweave-ai/airweave",
                },
                sync_immediately=True,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_source_connection(
            name=name,
            short_name=short_name,
            description=description,
            config_fields=config_fields,
            collection=collection,
            cron_schedule=cron_schedule,
            auth_fields=auth_fields,
            sync_immediately=sync_immediately,
            request_options=request_options,
        )
        return _response.data

    async def get_source_connection(
        self,
        source_connection_id: str,
        *,
        show_auth_fields: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Retrieve a specific source connection by its ID.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        show_auth_fields : typing.Optional[bool]
            Whether to reveal authentication credentials.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.get_source_connection(
                source_connection_id="source_connection_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_source_connection(
            source_connection_id, show_auth_fields=show_auth_fields, request_options=request_options
        )
        return _response.data

    async def update_source_connection(
        self,
        source_connection_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        auth_fields: typing.Optional[SourceConnectionUpdateAuthFields] = OMIT,
        config_fields: typing.Optional[ConfigValues] = OMIT,
        cron_schedule: typing.Optional[str] = OMIT,
        connection_id: typing.Optional[str] = OMIT,
        white_label_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Update a source connection's properties.

        <br/><br/>

        Modify the configuration of an existing source connection including its name,
        authentication credentials, configuration fields, sync schedule, or source-specific settings.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection to update

        name : typing.Optional[str]
            Updated name for the source connection. Must be between 4 and 42 characters.

        description : typing.Optional[str]
            Updated description of what this source connection provides.

        auth_fields : typing.Optional[SourceConnectionUpdateAuthFields]
            Updated authentication credentials for the data source. Provide new credentials to refresh or update authentication.

        config_fields : typing.Optional[ConfigValues]
            Source-specific configuration parameters required for data extraction. These vary by source type and control how data is retrieved (e.g., database queries, API filters, file paths). Check the documentation of a specific source (for example [Github](https://docs.airweave.ai/docs/connectors/github)) to see what is required.

        cron_schedule : typing.Optional[str]
            Updated cron expression for automatic synchronization schedule. Set to null to disable automatic syncing.

        connection_id : typing.Optional[str]
            Internal connection identifier. This is typically managed automatically and should not be modified manually.

        white_label_id : typing.Optional[str]
            ID of the white label integration. Used for custom OAuth integrations with your own branding.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.update_source_connection(
                source_connection_id="source_connection_id",
                name="GitHub - Updated Engineering Documentation",
                description="Updated: Now includes API documentation and code examples from multiple repositories",
                auth_fields={
                    "personal_access_token": "ghp_yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy",
                    "repo_name": "airweave-ai/engineering-docs",
                },
                config_fields={"branch": "develop"},
                cron_schedule="0 */4 * * *",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_source_connection(
            source_connection_id,
            name=name,
            description=description,
            auth_fields=auth_fields,
            config_fields=config_fields,
            cron_schedule=cron_schedule,
            connection_id=connection_id,
            white_label_id=white_label_id,
            request_options=request_options,
        )
        return _response.data

    async def delete_source_connection(
        self,
        source_connection_id: str,
        *,
        delete_data: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnection:
        """
        Delete a source connection.

        <br/><br/>

        Permanently removes the source connection configuration and credentials.
        By default, previously synced data remains in your destination systems for continuity.
        Use delete_data=true to also remove all associated data from destination systems.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection to delete

        delete_data : typing.Optional[bool]
            Whether to also delete all synced data from destination systems

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnection
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.delete_source_connection(
                source_connection_id="source_connection_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_source_connection(
            source_connection_id, delete_data=delete_data, request_options=request_options
        )
        return _response.data

    async def run_source_connection(
        self,
        source_connection_id: str,
        *,
        access_token: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SourceConnectionJob:
        """
        Manually trigger a data sync for this source connection.

        <br/><br/>
        Starts an immediate synchronization job that extracts fresh data from your source,
        transforms it according to your configuration, and updates the destination systems.
        The job runs asynchronously and endpoint returns immediately with tracking information.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection to sync

        access_token : typing.Optional[str]
            This parameter gives you the ability to start a sync job with an access token for an OAuth2.0 source directly instead of using the credentials that Airweave has stored for you. Learn more about direct token injection [here](https://docs.airweave.ai/direct-token-injection).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnectionJob
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.run_source_connection(
                source_connection_id="source_connection_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.run_source_connection(
            source_connection_id, access_token=access_token, request_options=request_options
        )
        return _response.data

    async def list_source_connection_jobs(
        self, source_connection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[SourceConnectionJob]:
        """
        List all sync jobs for a source connection.

        <br/><br/>
        Returns the complete history of data synchronization jobs including successful syncs,
        failed attempts, and currently running operations.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[SourceConnectionJob]
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.list_source_connection_jobs(
                source_connection_id="source_connection_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_source_connection_jobs(
            source_connection_id, request_options=request_options
        )
        return _response.data

    async def get_source_connection_job(
        self, source_connection_id: str, job_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SourceConnectionJob:
        """
        Get detailed information about a specific sync job.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        job_id : str
            The unique identifier of the sync job

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnectionJob
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.get_source_connection_job(
                source_connection_id="source_connection_id",
                job_id="job_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_source_connection_job(
            source_connection_id, job_id, request_options=request_options
        )
        return _response.data

    async def cancel_source_connection_job(
        self, source_connection_id: str, job_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SourceConnectionJob:
        """
        Cancel a running sync job.

        <br/><br/>
        Sends a cancellation signal to stop an in-progress data synchronization.
        The job will complete its current operation and then terminate gracefully.
        Only jobs in 'created', 'pending', or 'in_progress' states can be cancelled.

        Parameters
        ----------
        source_connection_id : str
            The unique identifier of the source connection

        job_id : str
            The unique identifier of the sync job to cancel

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SourceConnectionJob
            Successful Response

        Examples
        --------
        import asyncio

        from airweave import AsyncAirweaveSDK

        client = AsyncAirweaveSDK(
            api_key="YOUR_API_KEY",
            organization_id="YOUR_ORGANIZATION_ID",
        )


        async def main() -> None:
            await client.source_connections.cancel_source_connection_job(
                source_connection_id="source_connection_id",
                job_id="job_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.cancel_source_connection_job(
            source_connection_id, job_id, request_options=request_options
        )
        return _response.data
